==> grafana-9.0.2.tar.gz: grafana-9.0.2/packages/grafana-ui/src/components/Forms/Legacy/Select/Select.story.internal.tsx <==
import { action } from '@storybook/addon-actions';
import { Meta, Story } from '@storybook/react';
import React, { useState, useCallback } from 'react';

import { SelectableValue } from '@grafana/data';

import { UseState } from '../../../../utils/storybook/UseState';
import { withCenteredStory } from '../../../../utils/storybook/withCenteredStory';

import { Select, AsyncSelect as AsyncSelectComponent } from './Select';

export default {
  title: 'Forms/Legacy/Select',
  component: Select,
  decorators: [withCenteredStory],
  parameters: {
    controls: {
      exclude: [
        'className',
        'menuPlacement',
        'menuPosition',
        'maxMenuHeight',
        'minMenuHeight',
        'maxVisibleValues',
        'prefix',
        'renderControl',
        'value',
        'tooltipContent',
        'components',
        'inputValue',
        'id',
        'inputId',
        'defaultValue',
        'loading',
        'aria-label',
        'noOptionsMessage',
        'onChange',
        'onBlur',
        'onKeyDown',
        'filterOption',
        'formatCreateLabel',
        'getOptionLabel',
        'getOptionValue',
        'onCloseMenu',
        'onCreateOption',
        'onInputChange',
        'onOpenMenu',
        'isOptionDisabled',
      ],
    },
  },
  argTypes: {
    width: { control: { type: 'range', min: 5, max: 30 } },
  },
} as Meta;

const initialValue: SelectableValue<string> = { label: 'A label', value: 'A value' };

const options = [
  initialValue,
  { label: 'Another label', value: 'Another value 1' },
  { label: 'Another label', value: 'Another value 2' },
  { label: 'Another label', value: 'Another value 3' },
  { label: 'Another label', value: 'Another value 4' },
  { label: 'Another label', value: 'Another value 5' },
  { label: 'Another label', value: 'Another value ' },
];

export const Basic: Story = (args) => {
  return (
    <UseState initialState={initialValue}>
      {(value, updateValue) => {
        return (
          <Select
            {...args}
            onChange={(value: SelectableValue<string>) => {
              action('onChanged fired')(value);
              updateValue(value);
            }}
          />
        );
      }}
    </UseState>
  );
};
Basic.args = {
  placeholder: 'Choose...',
  options: options,
  width: 20,
};

export const AsyncSelect: Story = (args) => {
  const [isLoading, setIsLoading] = useState<boolean>(args.loading);
  const [asyncValue, setAsyncValue] = useState<SelectableValue<any>>();
  const loadAsyncOptions = useCallback((inputValue) => {
    return new Promise<Array<SelectableValue<string>>>((resolve) => {
      setTimeout(() => {
        setIsLoading(false);
        resolve(options.filter((option) => option.label && option.label.includes(inputValue)));
      }, 1000);
    });
  }, []);
  return (
    <AsyncSelectComponent
      {...args}
      value={asyncValue}
      isLoading={isLoading}
      loadOptions={loadAsyncOptions}
      onChange={(value) => {
        action('onChange')(value);
        setAsyncValue(value);
      }}
    />
  );
};
AsyncSelect.args = {
  loading: true,
  defaultOptions: true,
  width: 20,
};

==> grafana-9.4.3.tar.gz: grafana-9.4.3/packages/grafana-ui/src/components/Forms/Legacy/Select/Select.story.internal.tsx <==
import { action } from '@storybook/addon-actions';
import { useArgs } from '@storybook/client-api';
import { ComponentMeta, ComponentStory } from '@storybook/react';
import React, { useCallback } from 'react';

import { SelectableValue } from '@grafana/data';

import { withCenteredStory } from '../../../../utils/storybook/withCenteredStory';

import { Select, AsyncSelect as AsyncSelectComponent } from './Select';

const meta: ComponentMeta<typeof Select> = {
  title: 'Forms/Legacy/Select',
  component: Select,
  decorators: [withCenteredStory],
  parameters: {
    controls: {
      exclude: [
        'className',
        'menuPlacement',
        'menuPosition',
        'maxMenuHeight',
        'minMenuHeight',
        'maxVisibleValues',
        'prefix',
        'renderControl',
        'value',
        'tooltipContent',
        'components',
        'inputValue',
        'id',
        'inputId',
        'defaultValue',
        'aria-label',
        'noOptionsMessage',
        'onChange',
        'onBlur',
        'onKeyDown',
        'filterOption',
        'formatCreateLabel',
        'getOptionLabel',
        'getOptionValue',
        'onCloseMenu',
        'onCreateOption',
        'onInputChange',
        'onOpenMenu',
        'isOptionDisabled',
      ],
    },
  },
  argTypes: {
    width: { control: { type: 'range', min: 5, max: 30 } },
  },
};

const initialValue: SelectableValue<string> = { label: 'A label', value: 'A value' };

const options = [
  initialValue,
  { label: 'Another label', value: 'Another value 1' },
  { label: 'Another label', value: 'Another value 2' },
  { label: 'Another label', value: 'Another value 3' },
  { label: 'Another label', value: 'Another value 4' },
  { label: 'Another label', value: 'Another value 5' },
  { label: 'Another label', value: 'Another value ' },
];

export const Basic: ComponentStory<typeof Select> = (args) => {
  const [, updateArgs] = useArgs();
  return (
    <Select
      {...args}
      onChange={(value) => {
        action('onChange fired')(value);
        updateArgs({ value });
      }}
    />
  );
};
Basic.args = {
  placeholder: 'Choose...',
  options: options,
  width: 20,
};

export const AsyncSelect: ComponentStory<typeof AsyncSelectComponent> = (args) => {
  const [, updateArgs] = useArgs();
  const loadAsyncOptions = useCallback(
    (inputValue) => {
      return new Promise<Array<SelectableValue<string>>>((resolve) => {
        setTimeout(() => {
          updateArgs({ isLoading: false });
          resolve(options.filter((option) => option.label && option.label.includes(inputValue)));
        }, 1000);
      });
    },
    [updateArgs]
  );
  return (
    <AsyncSelectComponent
      {...args}
      loadOptions={loadAsyncOptions}
      onChange={(value) => {
        action('onChange')(value);
        updateArgs({ value });
      }}
    />
  );
};
AsyncSelect.args = {
  isLoading: true,
  defaultOptions: true,
  width: 20,
};

export default meta;
